This patch unifies the use of config options in v2 to all start with CONFIG_

It's basically done with the following script and some manual fixup:

VARS=`grep ^define src/config/Options.lb | cut -f2 -d\ | grep -v ^CONFIG | grep -v ^COREBOOT |grep -v ^CC`
for VAR in $VARS; do
	find . -name .svn -prune -o -type f -exec perl -pi -e "s/(^|[^0-9a-zA-Z_]+)$VAR($|[^0-9a-zA-Z_]+)/\1CONFIG_$VAR\2/g" {} \;
done

Signed-off-by: Stefan Reinauer <stepan@coresystems.de>
Acked-by: Ronald G. Minnich <rminnich@gmail.com>



git-svn-id: svn://svn.coreboot.org/coreboot/trunk@4381 2b7e53f0-3cfb-0310-b3e9-8179ed1497e1
diff --git a/src/lib/version.c b/src/lib/version.c
index 404f50d..2c84c4a 100644
--- a/src/lib/version.c
+++ b/src/lib/version.c
@@ -1,10 +1,10 @@
 #include <version.h>
 
 #ifndef MAINBOARD_VENDOR
 #error MAINBOARD_VENDOR not defined
 #endif
 #ifndef MAINBOARD_PART_NUMBER
 #error  MAINBOARD_PART_NUMBER not defined
 #endif
 
 #ifndef COREBOOT_VERSION
@@ -39,8 +39,8 @@
 #define COREBOOT_EXTRA_VERSION ""
 #endif
 
-const char mainboard_vendor[] = MAINBOARD_VENDOR;
-const char mainboard_part_number[] = MAINBOARD_PART_NUMBER;
+const char mainboard_vendor[] = CONFIG_MAINBOARD_VENDOR;
+const char mainboard_part_number[] = CONFIG_MAINBOARD_PART_NUMBER;
 
 const char coreboot_version[] = COREBOOT_VERSION;
 const char coreboot_extra_version[] = COREBOOT_EXTRA_VERSION;
@@ -1,10 +1,10 @@
 #include <version.h>
 
-#ifndef MAINBOARD_VENDOR
-#error MAINBOARD_VENDOR not defined
+#ifndef CONFIG_MAINBOARD_VENDOR
+#error CONFIG_MAINBOARD_VENDOR not defined
 #endif
@@ -1,10 +1,10 @@
 #endif
-#ifndef MAINBOARD_PART_NUMBER
-#error  MAINBOARD_PART_NUMBER not defined
+#ifndef CONFIG_MAINBOARD_PART_NUMBER
+#error  CONFIG_MAINBOARD_PART_NUMBER not defined
 #endif
 